@@ -74,9 +74,20 @@ for blocked_module in [
     if blocked_module not in demandimport.ignore:
         demandimport.ignore.append(blocked_module)
 
+try:
+    is_demandimport_enabled = demandimport.isenabled
+except AttributeError:
+    # Mercurial < 2.9.1
+    def is_demandimport_enabled():
+        return __import__ == demandimport.demandimport
+
+# Shut up warning about uninitialized logging for new keyring versions
+import logging
+logging.getLogger("keyring").addHandler(logging.NullHandler())
+
 # Temporarily disable demandimport to make the need of extending
 # the list above less likely.
-if demandimport.isenabled():
+if is_demandimport_enabled():
     demandimport.disable()
     try:
         import keyring
@@ -145,7 +156,7 @@ class PasswordStore(object):
         # keyring in general expects unicode. Mercurial provides "local" encoding. See #33
         password = encoding.fromlocal(password).decode('utf-8')
         keyring.set_password(KEYRING_SERVICE,
-                             pwdkey, 
+                             pwdkey,
                              password)
 
 password_store = PasswordStore()
